==> biodiv_4_1-2.zip: plugins/biodiv/lang/observation_fr.php <==
<?php

/*******************************************************************************\
 * BIODIV, plugin et squelette pour SPIP - https://www.spip.net/               *
 *         dédié à la gestion d'observations naturalistes                      *
 *                                                                             *
 *         Copyright (C) 2008-2020 Renaud LAURETTE                             *
 *                                                                             *
 * BIODIV a été développé initialement pour le projet Biodiv.Balma de l'APCVEB *
 * (Association de Protection du Cadre de Vie et de l'Environnement balmanais) * 
 *     voir Biodiv.Balma : https://balma.biodiv.fr/                            *
 *     voir APCVEB : http://apcveb.free.fr/                                    *
 *                                                                             *
 *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.         *
 *  Pour plus de détails voir les fichier COPYING.txt et LICENCE-BIODIV.md     *
\*******************************************************************************/

// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'ajouter_lien_observation' => 'Ajouter cette observation',
	'affectation_inconnue' => 'Affectation inconnue',
	'affectation_reussie' => 'Affectation réussie',
	'affectation_supprimee' => 'Affectation supprimée',

	// B
	'bouton_detacher' => 'Détacher',
	'bouton_supprimer' => 'Supprimer',
	
	// C
	'champ_adresse_explication' => 'Adresse dans la commune',
	'champ_adresse_label' => 'Adresse',
	'champ_commune_explication' => 'Nom de la commune',
	'champ_commune_label' => 'Commune',
	'champ_creation_label' => 'Création',
	'champ_date_obs_explication' => 'Date de l\'observation',
	'champ_date_obs_label' => 'Date de l\'observation',
	'champ_denombrement_explication' => 'Méthode de dénombrement',
	'champ_denombrement_label' => 'Méthode de dénombrement',
	'champ_descriptif_explication' => 'Description de l\'observation',
	'champ_descriptif_label' => 'Descriptif',
	'champ_discret_explication' => 'Confidentialité de l\'observation',
	'champ_discret_label' => 'Discret',
	'champ_espece_explication' => 'Espèce supposée (ou \'aucune\')',
	'champ_espece_label' => 'Espèce',
	'champ_id_espece_label' => 'Identifiant espèce',
	'champ_id_famille_label' => 'Identifiant famille',
	'champ_id_source_label' => 'Identifiant de la source',
	'champ_id_sujet_label' => 'Identifiant du sujet',
	'champ_insee_explication' => 'Code INSEE de la commune',
	'champ_insee_label' => 'Insee',
	'champ_lat_explication' => 'Latitude de l\'observation',
	'champ_lat_label' => 'Latitude',
	'champ_lng_explication' => 'Longitude GPS de l\'observation',
	'champ_lng_label' => 'Longitude',
	'champ_pjour_explication' => 'Période du jour',
	'champ_pjour_label' => 'Période du jour',
	'champ_quantite_explication' => 'Nombre de spécimen observés',
	'champ_quantite_label' => 'Quantité',
	'champ_ref_source_label' => 'Référence dans la base source',
	'champ_titre_explication' => 'Titre de l\'observation',
	'champ_titre_label' => 'Titre',
	'champ_type_obs_explication' => 'Type d\'observation',
	'champ_type_obs_label' => 'Type d\'observation',
	'confirmer_supprimer_observation' => 'Confirmez-vous la suppression de cette observation ?',

	// Pseudo-champs
	'champ_auteur_label' => 'Observateur',
	'champ_id_auteur_label' => 'Identifiant de l\'observateur',
	
	// Enumération générique
	'enum_any' => 'Indifférent',
	// Enumération dénombrement
	'enum_denombrement_co' => 'comptage',
	'enum_denombrement_es' => 'estimation',
	'enum_denombrement_ca' => 'calcul',
	'enum_denombrement_nsp' => 'ne sait pas',
	// Enumération discret
	'enum_discret_oui' => 'confidentiel',
	'enum_discret_non' => 'non confidentiel',
	'enum_discret_inconnu' => 'ne sait pas',
	// Enumération période du jour
	'enum_pjour_lever_du_soleil' => 'lever du soleil',
	'enum_pjour_matin' => 'matin',
	'enum_pjour_apres_midi' => 'après-midi',
	'enum_pjour_coucher_du_soleil' => 'coucher du soleil',
	'enum_pjour_nuit' => 'nuit',
	// Enumération type d'observation
	'enum_type_obs_espece' => 'espèce',
	'enum_type_obs_autre' => 'autre',

	// E
	'erreur_lien_observation' => 'Erreur sur la validité du lien',
	'exporter' => 'Exporter',
	'export_sinp' => 'Exporter au standard SINP',
	
	// H
	'hors_perimetre' => 'Observation hors périmètre',
	'hors_periode' => 'Observation hors période',
	
	// I
	'icone_creer_observation' => 'Créer une observation',
	'icone_modifier_observation' => 'Modifier cette observation',
	'info_1_observation' => 'Un biodiv observation',
	'info_aucun_observation' => 'Aucune observation',
	'info_biodiv_observations_auteur' => 'Les observations de cet auteur',
	'info_nb_biodiv_observations' => '@nb@ observations',
	'info_regne' => 'Règne',
	'info_date_de' => 'Date de début',
	'info_date_a' => 'Date de fin',
	'info_perimetre' => 'Périmètre',
	'info_format' => 'Format d\'export',

	// Messages de formulaires - dépouiller observation
	'msg_document_inconnu' => 'Document inconnu',
	'msg_document_supprime_ok' => 'Document supprimé',
	'msg_document_supprime_echec' => 'Echec: le document n\'a pas pu être supprimé',
	// Messages de formulaires - illustrer ou documenter observation
	'msg_observation_inconnue' => 'Observation inconnue',
	'msg_acces_concurrent' => 'Accès concurrent détecté',
	'msg_extension_refusee' => 'Type de fichier non autorisé',
	'msg_fichier_trop_gros' => 'Fichier trop gros',
	'msg_fichier_absent' => 'Pas de fichier trouvé',
	'msg_telechargement_echec' => 'Echec du téléchargement',
	'msg_telechargement_ok' => 'Téléchargement réussi',
	// Messages de formulaires - supprimer observation
	'msg_confirmer_supprimer_obs' => 'Confirmez-vous la suppression de l\'observation ?',
	'msg_suppression_doclie_echec' => 'La suppression des documents liés à l\'observation a échoué',
	'msg_suppression_observation_echec' => 'La suppression de l\'observation a échoué',
	'msg_suppression_observation_refus' => 'La suppression de l\'observation a été refusée',
	'msg_suppression_observation_ok' => 'L\'observation a été supprimée',
	// Messages de formulaires - lier/délier observation
	'msg_lier_observation' => 'Lier une observation',	
	'msg_choisir_observation' => 'Choisissez une observation',
	'msg_lier_selection_obligatoire' => 'Sélection obligatoire',
	'msg_lier_erreur_contexte' => 'Formulaire hors contexte',
	'msg_lier_erreur_type' => 'Ce type d\'observation ne peut pas être lié',
	'msg_lier_abandon' => 'Abandon de l\'opération',
	'msg_lier_ok' => 'Observation @obs@ liée avec succès',
	'msg_lier_echec' => 'Echec lors de la liaison de l\'observation @obs@ : \'@err@\'',
	'msg_lier_taxon_discret' => 'Ce taxon est sensible : le statut de confidentialité de l\'observation a été mis à jour.',
	'msg_delier_observation' => 'Délier une observation',
	'msg_delier_ok' => 'Observation @obs@ déliée avec succès',
	'msg_delier_echec' => 'Echec lors de la dissociation de l\'observation @obs@ : \'@err@\'',

	// R
	'retirer_lien_observation' => 'Retirer cette observation',
	'retirer_tous_liens_biodiv_observations' => 'Retirer toutes les observations',

	// S
	'supprimer_observation' => 'Supprimer cette observation',

	// T
	'texte_ajouter_observation' => 'Ajouter une observation',
	'texte_changer_statut_observation' => 'Cette observation est :',
	'texte_creer_associer_observation' => 'Créer et associer une observation',
	'texte_definir_comme_traduction_observation' => 'Cette observation est une traduction de l\'observation numéro :',
	'titre_biodiv_observations' => 'Observations',
	'titre_biodiv_observations_rubrique' => 'Observations de la rubrique',
	'titre_langue_observation' => 'Langue de cette observation',
	'titre_logo_observation' => 'Logo de cette observation',
	'titre_objets_lies_observation' => 'Liés à cette observation',
	'titre_observation' => 'Observation',
);

==> biodiv_4_3.zip: plugins/biodiv/lang/observation_fr.php <==
<?php

/*******************************************************************************\
 * BIODIV, plugin et squelette pour SPIP - https://www.spip.net/               *
 *         dédié à la gestion d'observations naturalistes                      *
 *                                                                             *
 *         Copyright (C) 2008-2020 Renaud LAURETTE                             *
 *                                                                             *
 * BIODIV a été développé initialement pour le projet Biodiv.Balma de l'APCVEB *
 * (Association de Protection du Cadre de Vie et de l'Environnement balmanais) * 
 *     voir Biodiv.Balma : https://balma.biodiv.fr/                            *
 *     voir APCVEB : http://apcveb.free.fr/                                    *
 *                                                                             *
 *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.         *
 *  Pour plus de détails voir les fichier COPYING.txt et LICENCE-BIODIV.md     *
\*******************************************************************************/

// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'ajouter_lien_observation' => 'Ajouter cette observation',
	'affectation_inconnue' => 'Affectation inconnue',
	'affectation_reussie' => 'Affectation réussie',
	'affectation_supprimee' => 'Affectation supprimée',

	// B
	'bouton_detacher' => 'Détacher',
	'bouton_supprimer' => 'Supprimer',
	
	// C
	'champ_adresse_explication' => 'Adresse dans la commune',
	'champ_adresse_label' => 'Adresse',
	'champ_commune_explication' => 'Nom de la commune',
	'champ_commune_label' => 'Commune',
	'champ_creation_label' => 'Création',
	'champ_date_obs_explication' => 'Date de l\'observation',
	'champ_date_obs_label' => 'Date de l\'observation',
	'champ_denombrement_explication' => 'Méthode de dénombrement',
	'champ_denombrement_label' => 'Méthode de dénombrement',
	'champ_descriptif_explication' => 'Description de l\'observation',
	'champ_descriptif_label' => 'Descriptif',
	'champ_discret_explication' => 'Confidentialité de l\'observation',
	'champ_discret_label' => 'Discret',
	'champ_espece_explication' => 'Espèce supposée (ou \'aucune\')',
	'champ_espece_label' => 'Espèce',
	'champ_id_espece_label' => 'Identifiant espèce',
	'champ_id_famille_label' => 'Identifiant famille',
	'champ_id_source_label' => 'Identifiant de la source',
	'champ_id_sujet_label' => 'Identifiant du sujet',
	'champ_insee_explication' => 'Code INSEE de la commune',
	'champ_insee_label' => 'Insee',
	'champ_lat_explication' => 'Latitude de l\'observation',
	'champ_lat_label' => 'Latitude',
	'champ_lng_explication' => 'Longitude GPS de l\'observation',
	'champ_lng_label' => 'Longitude',
	'champ_pjour_explication' => 'Période du jour',
	'champ_pjour_label' => 'Période du jour',
	'champ_quantite_explication' => 'Nombre de spécimen observés',
	'champ_quantite_label' => 'Quantité',
	'champ_ref_source_label' => 'Référence dans la base source',
	'champ_titre_explication' => 'Titre de l\'observation',
	'champ_titre_label' => 'Titre',
	'champ_type_obs_explication' => 'Type d\'observation',
	'champ_type_obs_label' => 'Type d\'observation',
	'confirmer_supprimer_observation' => 'Confirmez-vous la suppression de cette observation ?',

	// Pseudo-champs
	'champ_auteur_label' => 'Observateur',
	'champ_id_auteur_label' => 'Identifiant de l\'observateur',
	
	// D
	'delier' => 'Délier',
	
	// Enumération générique
	'enum_any' => 'Indifférent',
	// Enumération dénombrement
	'enum_denombrement_co' => 'comptage',
	'enum_denombrement_es' => 'estimation',
	'enum_denombrement_ca' => 'calcul',
	'enum_denombrement_nsp' => 'ne sait pas',
	// Enumération discret
	'enum_discret_oui' => 'confidentiel',
	'enum_discret_non' => 'non confidentiel',
	'enum_discret_inconnu' => 'ne sait pas',
	// Enumération période du jour
	'enum_pjour_lever_du_soleil' => 'lever du soleil',
	'enum_pjour_matin' => 'matin',
	'enum_pjour_apres_midi' => 'après-midi',
	'enum_pjour_coucher_du_soleil' => 'coucher du soleil',
	'enum_pjour_nuit' => 'nuit',
	// Enumération type d'observation
	'enum_type_obs_espece' => 'espèce',
	'enum_type_obs_autre' => 'autre',

	// E
	'erreur_lien_observation' => 'Erreur sur la validité du lien',
	'exporter' => 'Exporter',
	'export_sinp' => 'Exporter au standard SINP',
	
	// H
	'hors_perimetre' => 'Observation hors périmètre',
	'hors_periode' => 'Observation hors période',
	
	// I
	'icone_creer_observation' => 'Créer une observation',
	'icone_modifier_observation' => 'Modifier cette observation',
	'inclassable' => 'inclassable',
	'info_1_observation' => 'Un biodiv observation',
	'info_aucun_observation' => 'Aucune observation',
	'info_biodiv_observations_auteur' => 'Les observations de cet auteur',
	'info_nb_biodiv_observations' => '@nb@ observations',
	'info_regne' => 'Règne',
	'info_date_de' => 'Date de début',
	'info_date_a' => 'Date de fin',
	'info_perimetre' => 'Périmètre',
	'info_format' => 'Format d\'export',
	'inverser' => 'Inverser classable/inclassable',

	// Messages de formulaires - dépouiller observation
	'msg_document_inconnu' => 'Document inconnu',
	'msg_document_supprime_ok' => 'Document supprimé',
	'msg_document_supprime_echec' => 'Echec: le document n\'a pas pu être supprimé',
	// Messages de formulaires - illustrer ou documenter observation
	'msg_observation_inconnue' => 'Observation inconnue',
	'msg_acces_concurrent' => 'Accès concurrent détecté',
	'msg_extension_refusee' => 'Type de fichier non autorisé',
	'msg_fichier_trop_gros' => 'Fichier trop gros',
	'msg_fichier_absent' => 'Pas de fichier trouvé',
	'msg_telechargement_echec' => 'Echec du téléchargement',
	'msg_telechargement_ok' => 'Téléchargement réussi',
	// Messages de formulaires - supprimer observation
	'msg_confirmer_supprimer_obs' => 'Confirmez-vous la suppression de l\'observation ?',
	'msg_suppression_doclie_echec' => 'La suppression des documents liés à l\'observation a échoué',
	'msg_suppression_observation_echec' => 'La suppression de l\'observation a échoué',
	'msg_suppression_observation_refus' => 'La suppression de l\'observation a été refusée',
	'msg_suppression_observation_ok' => 'L\'observation a été supprimée',
	// Messages de formulaires - lier/délier observation
	'msg_lier_observation' => 'Lier une observation',	
	'msg_choisir_observation' => 'Choisissez une observation',
	'msg_lier_selection_obligatoire' => 'Sélection obligatoire',
	'msg_lier_erreur_contexte' => 'Formulaire hors contexte',
	'msg_lier_erreur_type' => 'Ce type d\'observation ne peut pas être lié',
	'msg_lier_abandon' => 'Abandon de l\'opération',
	'msg_lier_ok' => 'Observation @obs@ liée avec succès',
	'msg_lier_echec' => 'Echec lors de la liaison de l\'observation @obs@ : \'@err@\'',
	'msg_lier_taxon_discret' => 'Ce taxon est sensible : le statut de confidentialité de l\'observation a été mis à jour.',
	'msg_delier_observation' => 'Délier une observation',	
	'msg_delier_ok' => 'Observation @obs@ déliée avec succès',
	'msg_delier_echec' => 'Echec lors de la dissociation de l\'observation @obs@ : \'@err@\'',	
	
	'msg_modifier_lien_observation' => 'Modifier le lien d\'une observation',
	'msg_ok_delier' => 'Observation @obs@ déliée avec succès',
	'msg_echec_delier' => 'Echec lors de la dissociation de l\'observation @obs@ : \'@err@\'',
	'msg_ok_changer' => 'Lien de l\'observation @obs@ modifié avec succès',
	'msg_echec_changer' => 'Echec lors de la modification du lien de l\'observation @obs@ : \'@err@\'',
	
	'modifier_lien' => 'Modifier le lien',

	// R
	'retirer_lien_observation' => 'Retirer cette observation',
	'retirer_tous_liens_biodiv_observations' => 'Retirer toutes les observations',

	// S
	'supprimer_observation' => 'Supprimer cette observation',

	// T
	'texte_ajouter_observation' => 'Ajouter une observation',
	'texte_changer_statut_observation' => 'Cette observation est :',
	'texte_creer_associer_observation' => 'Créer et associer une observation',
	'texte_definir_comme_traduction_observation' => 'Cette observation est une traduction de l\'observation numéro :',
	'titre_biodiv_observations' => 'Observations',
	'titre_biodiv_observations_rubrique' => 'Observations de la rubrique',
	'titre_langue_observation' => 'Langue de cette observation',
	'titre_logo_observation' => 'Logo de cette observation',
	'titre_objets_lies_observation' => 'Liés à cette observation',
	'titre_observation' => 'Observation',
);
